sqlobject.inheritance.tests.test_inheritance module — SQLObject 3.9.1 documentation

# sqlobject.inheritance.tests.test_inheritance module

class `sqlobject.inheritance.tests.test_inheritance.` `Employee`(**kw)

  Bases: `sqlobject.inheritance.tests.test_inheritance.InheritablePerson`

  property `firstName`
  `j` = employee
  property `lastName`
  `q` = employee
  property `so_position`
  class `sqlmeta`(instance)

    Bases: `sqlobject.declarative.sqlmeta`

    `childClasses` = {}
    `childName` = 'Employee'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `parentClass`

      alias of `sqlobject.inheritance.tests.test_inheritance.InheritablePerson`

    `soClass`

      alias of `sqlobject.inheritance.tests.test_inheritance.Employee`

    `table` = 'employee'

class `sqlobject.inheritance.tests.test_inheritance.` `InheritablePerson`(**kw)

  Bases: `sqlobject.inheritance.InheritableSQLObject`

  classmethod `byLastName`(val, connection=None)
  property `childName`
  property `firstName`
  `j` = inheritable_person
  property `lastName`
  `q` = inheritable_person
  class `sqlmeta`(instance)

    Bases: `sqlobject.inheritance.InheritableSQLMeta`

    `childClasses` = {'Employee': <class 'sqlobject.inheritance.tests.test_inheritance.Employee'>}
    `childName` = None
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `parentClass` = None
    `soClass`

      alias of `sqlobject.inheritance.tests.test_inheritance.InheritablePerson`

    `table` = 'inheritable_person'

`sqlobject.inheritance.tests.test_inheritance.` `setup`()

`sqlobject.inheritance.tests.test_inheritance.` `test_addDelColumn`()

`sqlobject.inheritance.tests.test_inheritance.` `test_creation_fail`()

`sqlobject.inheritance.tests.test_inheritance.` `test_inheritance`()

`sqlobject.inheritance.tests.test_inheritance.` `test_inheritance_select`()